@@ -63,17 +63,10 @@ class Stellar:
             steps.append(self.create_starting_cohort(f'{self.group}_cohort'))
             steps += list(self.all_utils(input_tbl_nm = f'{self.group}_cohort')) # Get all ER & IPs from 12m prior to current date - this method returns 2 queries
             steps.append(self.remove_ineligible_er_due_to_admit(ER_tbl_nm = f'{self.group}_er_all', IP_tbl_nm = f'{self.group}_ip_all', output_tbl_nm = f'{self.group}_er_eligible')) # Remove ER visits that resulted in an admit
-            
-            if self.stars:
-                ER_tbl_nm = f'{self.group}_er_eligible_stars'
-            
-            else:
-                ER_tbl_nm = f'{self.group}_er_eligible'
-                
-            steps += list(self.split_utils(cohort_tbl_nm = f'{self.group}_cohort', ER_tbl_nm = ER_tbl_nm, IP_tbl_nm = f'{self.group}_ip_all'))
+            steps += list(self.split_utils(cohort_tbl_nm = f'{self.group}_cohort', ER_tbl_nm = f'{self.group}_er_eligible', IP_tbl_nm = f'{self.group}_ip_all'))
 
             #----------------These steps are all to get follow-up rates---------------------------------
-            steps.append(self.unique_er_discharges(input_tbl_nm = ER_tbl_nm, # get follow-ups for ALL ED visits so can include gap closed flag on final table
+            steps.append(self.unique_er_discharges(input_tbl_nm = f'{self.group}_er_eligible', # get follow-ups for ALL ED visits so can include gap closed flag on final table
                                                    output_tbl_nm = f'{self.group}_er_unique'))
 
 
@@ -99,17 +92,7 @@ class Stellar:
             steps.append(self.demographics(cohort_tbl_nm = f'{self.group}_cohort'))
             steps.append(self.utilizations(cohort_tbl_nm = f'{self.group}_cohort'))
             steps.append(self.charlson_comorbidities(cohort_tbl_nm = f'{self.group}_cohort'))
-            
-            # If doing a stars analysis, return all the discharges
-            # if self.stars:
-            #     step12 = self.feature_tbl(cohort_tbl_nm = f'{self.group}_cohort', filter_to_obs_period=False)
-                
-            # # If doing the utilization analysis, filter discharges down to the correct observation period
-            # else:
-            #     step12 = self.feature_tbl(cohort_tbl_nm = f'{self.group}_cohort', filter_to_obs_period=True)
 
-            # steps = [step1, step2a, step2b, step3, step4a, step4b, step4c, step4d, step5, 
-            #          step6, step7, step8, step9, step10, step11, step12]
             
         # Control pipeline  
         else:
@@ -118,18 +101,9 @@ class Stellar:
             steps.append(self.mbi_to_pty_lookup(input_tbl_nm = f'{self.group}_pool', output_tbl_nm = f'{self.group}_pool_ptys', indexed_on_discharge=False))
             steps += list(self.all_utils(input_tbl_nm = f'{self.group}_pool_ptys')) # ER, IPs from 12m prior all the way through eval period after
             steps.append(self.remove_ineligible_er_due_to_admit(ER_tbl_nm = f'{self.group}_er_all', IP_tbl_nm = f'{self.group}_ip_all', output_tbl_nm = f'{self.group}_er_eligible'))
-            
-            if self.stars:
-                # This table will get created in using the remove_ineligible_due_to_ED() method
-                ER_tbl_nm = f'{self.group}_er_eligible_stars'
-            
-            else:
-                # This is just the volatile table created in the previous step
-                ER_tbl_nm = f'{self.group}_er_eligible'
-                
-            steps.append(self.narrow_to_observation_period(input_tbl_nm = ER_tbl_nm, output_tbl_nm = f'{self.group}_cohort_mbi'))
+            steps.append(self.narrow_to_observation_period(input_tbl_nm = f'{self.group}_er_eligible', output_tbl_nm = f'{self.group}_cohort_mbi'))
             steps.append(self.mbi_to_pty_lookup(input_tbl_nm = f'{self.group}_cohort_mbi', output_tbl_nm = f'{self.group}_cohort'))
-            steps += list(self.split_utils(cohort_tbl_nm = f'{self.group}_cohort', ER_tbl_nm = ER_tbl_nm, IP_tbl_nm = f'{self.group}_ip_all'))
+            steps += list(self.split_utils(cohort_tbl_nm = f'{self.group}_cohort', ER_tbl_nm = f'{self.group}_er_eligible', IP_tbl_nm = f'{self.group}_ip_all'))
 
             #----------------These steps are all to get follow-up rates---------------------------------
             steps.append(self.unique_er_discharges(input_tbl_nm = ER_tbl_nm, output_tbl_nm = f'{self.group}_er_unique')) # get follow-ups for ALL ED visits so can include gap closed flag on final table
@@ -150,8 +124,6 @@ class Stellar:
             steps.append(self.utilizations(cohort_tbl_nm = f'{self.group}_cohort'))
             steps.append(self.charlson_comorbidities(cohort_tbl_nm = f'{self.group}_cohort'))
 
-            # steps += self.feature_tbl(cohort_tbl_nm = f'{self.group}_cohort', filter_to_obs_period = False) # Want to get back all discharges from 11-04-2021 through 02-28-2022
-
             
         return steps
     
@@ -175,42 +147,17 @@ class Stellar:
             
         
         start = time.time()
-        
-        if self.stars:
-            
-            # Tell the for loop when to break to run the STARS-eligible algo
-            if pre_ER_steps is None and self.treatment:
-                pre_ER_steps = 4
-            
-            elif pre_ER_steps is None and not self.treatment:
-                pre_ER_steps = 5
-                
-            
-            for i, ele in enumerate(steps[:pre_ER_steps]):
-                print(f'Running step {i}...')
-                self.cur.execute(ele)
-                
-            # remove ineligible ER here
-            self.remove_ineligible_due_to_ed(input_tbl_nm = f'{self.group}_er_eligible', output_tbl_nm = f'{self.group}_er_eligible_stars')
-            
-            for i, ele in enumerate(steps[pre_ER_steps:]):
-                print(f'Running step {pre_ER_steps+1}...')
-                self.cur.execute(ele)
-            
-        
-        else:
-        
-            # Can run all the queries straight through for the affordability analysis
-            for i, ele in enumerate(steps):
-                print(f'Running step {i}...')
-                self.cur.execute(ele)
+
+        for i, ele in enumerate(steps):
+            print(f'Running step {i}...')
+            self.cur.execute(ele)
             
         end = time.time()
         
         # self.get_params()
         print('Time to load data was: {} min.'.format(round((end - start)/60, 1)))
         
-    def build_feature_tbl(self, tbls = None):
+    def build_feature_tbl(self, stars_analysis, tbls = None):
         
         if tbls is None:
             
@@ -220,11 +167,7 @@ class Stellar:
         print('Building feature table...')
                 
         # If doing a utilization analysis, filter discharges down to the correct observation period
-        if self.stars:        
-            sql = self.feature_tbl2(cohort_tbl_nm = f'{self.group}_cohort', filter_to_obs_period = False, tbls = tbls)
-            
-        else:            
-            sql = self.feature_tbl2(cohort_tbl_nm = f'{self.group}_cohort', filter_to_obs_period = True, tbls = tbls)
+        sql = self.feature_tbl(cohort_tbl_nm = f'{self.group}_cohort', stars_analysis = stars_analysis, tbls = tbls)
 
         start = time.time()
         self.cur.execute(sql)
@@ -232,7 +175,7 @@ class Stellar:
         
         print('Time to load data was: {} min.'.format(round((end - start)/60, 1)))
         
-    def get_feature_tbl(self):
+    def get_feature_tbl(self, stars):
         '''
         
 
@@ -250,8 +193,17 @@ class Stellar:
         else:
             
             trt = 0
+            
+        if stars:
+            
+            tbl_nm = f'{self.group}_feature_tbl_stars'
+            
+        else:
+           
+            tbl_nm = f'{self.group}_feature_tbl_utils'
+            
         
-        tbl = pd.read_sql(f'SELECT a.*, {trt} as treatment FROM {self.group}_feature_tbl a', self.con)
+        tbl = pd.read_sql(f'SELECT a.*, {trt} as treatment FROM {tbl_nm} a', self.con)
         
         return tbl
     
@@ -1646,7 +1598,7 @@ GROUP BY a.alt_id_val, a.er_discharge
         
         
     
-    def feature_tbl2(self, cohort_tbl_nm, filter_to_obs_period, tbls = None):
+    def feature_tbl(self, cohort_tbl_nm, stars_analysis, tbls = None):
         
         select_statement = ''
         join_statement = ''
@@ -1667,16 +1619,21 @@ GROUP BY a.alt_id_val, a.er_discharge
                     select_statement += f', {i}.{j}'
                  
         
-        if filter_to_obs_period:
+        if stars_analysis:
+            
+            where_statement = ''
+            output_tbl_nm = f'{self.group}_feature_tbl_stars'
+            
             
-            where_statement = f'WHERE a.er_discharge <= ADD_MONTHS(CURRENT_DATE(), -{self.months_in_eval_period}-1)'
         
         else:
             
-            where_statement = ''
+            where_statement = f'WHERE a.er_discharge <= ADD_MONTHS(CURRENT_DATE(), -{self.months_in_eval_period}-1)'
+            output_tbl_nm = f'{self.group}_feature_tbl_utils'
         
         
-        sql = f'''CREATE VOLATILE TABLE {self.group}_feature_tbl AS 
+        
+        sql = f'''CREATE VOLATILE TABLE {output_tbl_nm} AS 
             
             (SELECT a.alt_id_val, a.er_discharge, ADD_MONTHS(CURRENT_DATE(), -{self.months_in_eval_period}-1) as obs_period_end_date  {select_statement}
              FROM {cohort_tbl_nm} a
@@ -1698,96 +1655,96 @@ GROUP BY a.alt_id_val, a.er_discharge
         
         
     
-    def feature_tbl(self, cohort_tbl_nm, filter_to_obs_period = False, util_tbl_nm = None, demo_tbl_nm = None, fu_rate_tbl_nm = None, fu_tbl_nm = None):
-        '''
+    # def feature_tbl(self, cohort_tbl_nm, filter_to_obs_period = False, util_tbl_nm = None, demo_tbl_nm = None, fu_rate_tbl_nm = None, fu_tbl_nm = None):
+    #     '''
         
 
-        Parameters
-        ----------
-        cohort_tbl_nm : string
-            Name of volatile table containing cohort MBI's and index ER discharges.
-        filter_to_obs_period : boolean, optional
-            Should the ER discharges be filtered to the observation period? If the analysis is on utilization (affordability analysis), this should be set to True so
-            that the only discharges returned are in the observation period. If the analysis is on Hedis follow-up, then follow-up for all discharges to date should be evaluated.
-            The default is False.
-        util_tbl_nm : string, optional
-            The name of the volatile table that contains the utilization counts (IP, ER) for the members in the cohort table. The default is None.
-        demo_tbl_nm : string, optional
-            The name of the volatile table that contains the demographics (age, gender) for the members in the cohort table. The default is None.
-        fu_rate_tbl_nm : string, optional
-            The name of the volatile table that contains the follow-up rates for the covariate window and pre-index study period. The default is None.
-        fu_tbl_nm : string, optional
-            The name of the volatile table that contains the follow-up flag for the index ER discharges in the cohort table. The default is None.
+    #     Parameters
+    #     ----------
+    #     cohort_tbl_nm : string
+    #         Name of volatile table containing cohort MBI's and index ER discharges.
+    #     filter_to_obs_period : boolean, optional
+    #         Should the ER discharges be filtered to the observation period? If the analysis is on utilization (affordability analysis), this should be set to True so
+    #         that the only discharges returned are in the observation period. If the analysis is on Hedis follow-up, then follow-up for all discharges to date should be evaluated.
+    #         The default is False.
+    #     util_tbl_nm : string, optional
+    #         The name of the volatile table that contains the utilization counts (IP, ER) for the members in the cohort table. The default is None.
+    #     demo_tbl_nm : string, optional
+    #         The name of the volatile table that contains the demographics (age, gender) for the members in the cohort table. The default is None.
+    #     fu_rate_tbl_nm : string, optional
+    #         The name of the volatile table that contains the follow-up rates for the covariate window and pre-index study period. The default is None.
+    #     fu_tbl_nm : string, optional
+    #         The name of the volatile table that contains the follow-up flag for the index ER discharges in the cohort table. The default is None.
 
-        Returns
-        -------
-        sql : TYPE
-            Query to create the feature table for propensity-score matching for the instance's cohort.
+    #     Returns
+    #     -------
+    #     sql : TYPE
+    #         Query to create the feature table for propensity-score matching for the instance's cohort.
 
-        '''
+    #     '''
         
-        if util_tbl_nm is None:
+    #     if util_tbl_nm is None:
             
-            util_tbl_nm = f'{self.group}_utils'
+    #         util_tbl_nm = f'{self.group}_utils'
             
-        if demo_tbl_nm is None:
+    #     if demo_tbl_nm is None:
             
-            demo_tbl_nm = f'{self.group}_demographics'
+    #         demo_tbl_nm = f'{self.group}_demographics'
             
-        if fu_rate_tbl_nm is None:
+    #     if fu_rate_tbl_nm is None:
             
-            fu_rate_tbl_nm = f'{self.group}_fu_rates'
+    #         fu_rate_tbl_nm = f'{self.group}_fu_rates'
             
-        if fu_tbl_nm is None:
+    #     if fu_tbl_nm is None:
             
-            fu_tbl_nm = f'{self.group}_er_follow_ups'
+    #         fu_tbl_nm = f'{self.group}_er_follow_ups'
             
-        if filter_to_obs_period:
+    #     if filter_to_obs_period:
             
-            where_statement = f'WHERE a.er_discharge <= ADD_MONTHS(CURRENT_DATE(), -{self.months_in_eval_period}-1)'
+    #         where_statement = f'WHERE a.er_discharge <= ADD_MONTHS(CURRENT_DATE(), -{self.months_in_eval_period}-1)'
         
-        else:
+    #     else:
             
-            where_statement = ''
+    #         where_statement = ''
         
         
-        sql = f'''CREATE VOLATILE TABLE {self.group}_feature_tbl AS 
+    #     sql = f'''CREATE VOLATILE TABLE {self.group}_feature_tbl AS 
             
-            (SELECT DISTINCT a.alt_id_val, a.er_discharge, c.er_trt, c.ip_trt, 
-             /*b.ami, b.afib, b.alzh, b.ckd, b.copd, b.depr, b.heart, b.stroke,*/ 
-             c.er_12m, c.ip_12m, d.age, d.gender, e.fu_rate_12m, e.fu_rate_study, 
-             CASE WHEN f.stars_eligible_er_follow_up IS NULL THEN 0 ELSE f.stars_eligible_er_follow_up END AS hedis_follow_up,
-             {self.months_in_eval_period} AS months_in_outcome_period
-             FROM {cohort_tbl_nm} a
+    #         (SELECT DISTINCT a.alt_id_val, a.er_discharge, c.er_trt, c.ip_trt, 
+    #          /*b.ami, b.afib, b.alzh, b.ckd, b.copd, b.depr, b.heart, b.stroke,*/ 
+    #          c.er_12m, c.ip_12m, d.age, d.gender, e.fu_rate_12m, e.fu_rate_study, 
+    #          CASE WHEN f.stars_eligible_er_follow_up IS NULL THEN 0 ELSE f.stars_eligible_er_follow_up END AS hedis_follow_up,
+    #          {self.months_in_eval_period} AS months_in_outcome_period
+    #          FROM {cohort_tbl_nm} a
              
-              /*LEFT JOIN {self.group}_fmc b
-              ON a.alt_id_val = b.alt_id_val
-              AND a.er_discharge = b.er_discharge*/
+    #           /*LEFT JOIN {self.group}_fmc b
+    #           ON a.alt_id_val = b.alt_id_val
+    #           AND a.er_discharge = b.er_discharge*/
              
-             LEFT JOIN {util_tbl_nm} c
-             ON a.alt_id_val = c.alt_id_val
-             AND a.er_discharge = c.er_discharge
+    #          LEFT JOIN {util_tbl_nm} c
+    #          ON a.alt_id_val = c.alt_id_val
+    #          AND a.er_discharge = c.er_discharge
              
-             LEFT JOIN {demo_tbl_nm} d
-             ON a.alt_id_val = d.alt_id_val
-             AND a.er_discharge = d.er_discharge
+    #          LEFT JOIN {demo_tbl_nm} d
+    #          ON a.alt_id_val = d.alt_id_val
+    #          AND a.er_discharge = d.er_discharge
              
-             LEFT JOIN {fu_rate_tbl_nm} e
-             ON a.alt_id_val = e.alt_id_val
-             AND a.er_discharge = e.er_discharge
+    #          LEFT JOIN {fu_rate_tbl_nm} e
+    #          ON a.alt_id_val = e.alt_id_val
+    #          AND a.er_discharge = e.er_discharge
              
-             LEFT JOIN {fu_tbl_nm} f
-             ON a.alt_id_val = f.alt_id_val
-             AND a.er_discharge = f.er_discharge
+    #          LEFT JOIN {fu_tbl_nm} f
+    #          ON a.alt_id_val = f.alt_id_val
+    #          AND a.er_discharge = f.er_discharge
              
-             {where_statement} --Select only discharges that occurred w/ enough time to evaluate; additional -1 is for the lag in having FULL claims
+    #          {where_statement} --Select only discharges that occurred w/ enough time to evaluate; additional -1 is for the lag in having FULL claims
              
-                )
+    #             )
             
-            WITH DATA
-            ON COMMIT PRESERVE ROWS;
+    #         WITH DATA
+    #         ON COMMIT PRESERVE ROWS;
             
             
-            '''
+    #         '''
             
-        return sql
+    #     return sql
